@@ -1,5 +1,6 @@
 use clap::{AppSettings, Clap};
 use gitoxide_core as core;
+use std::ffi::OsString;
 use std::path::PathBuf;
 
 #[derive(Debug, Clap)]
@@ -44,10 +45,47 @@ pub struct Args {
 pub enum Subcommands {
     #[clap(setting = AppSettings::ColoredHelp)]
     #[clap(setting = AppSettings::DisableVersion)]
+    PackCreate {
+        #[clap(long, short = 'r')]
+        /// the directory containing the '.git' repository from which objects should be read.
+        repository: Option<PathBuf>,
+
+        #[clap(long, short = 'e', possible_values(core::pack::create::ObjectExpansion::variants()))]
+        /// the way objects are expanded. They differ in costs.
+        ///
+        /// Possible values are "none" and "tree-traversal". Default is "none".
+        expansion: Option<core::pack::create::ObjectExpansion>,
+
+        #[clap(long)]
+        /// if set, the counting phase may be accelerated using multithreading.
+        ///
+        /// On the flip side, however, one will loose deterministic counting results which affects the
+        /// way the resulting pack is structured.
+        nondeterministic_count: bool,
+
+        #[clap(long, short = 's')]
+        /// If set statistical information will be presented to inform about pack creation details.
+        /// It's a form of instrumentation for developers to help improve pack generation.
+        statistics: bool,
+
+        /// The directory into which to write the pack file.
+        #[clap(long, short = 'o')]
+        output_directory: Option<PathBuf>,
+
+        /// The tips from which to start the commit graph iteration, either as fully qualified commit hashes
+        /// or as branch names.
+        ///
+        /// If empty, we expect to read objects on stdin and default to 'none' as expansion mode.
+        /// Otherwise the expansion mode is 'tree-traversal' by default.
+        tips: Vec<OsString>,
+    },
+    #[clap(setting = AppSettings::ColoredHelp)]
+    #[clap(setting = AppSettings::DisableVersion)]
+    #[cfg(any(feature = "gitoxide-core-async-client", feature = "gitoxide-core-blocking-client"))]
     PackReceive {
         /// The protocol version to use. Valid values are 1 and 2
         #[clap(long, short = 'p')]
-        protocol: Option<core::Protocol>,
+        protocol: Option<core::net::Protocol>,
 
         /// the directory into which to write references. Existing files will be overwritten.
         ///
@@ -57,7 +95,7 @@ pub enum Subcommands {
 
         /// The URLs or path from which to receive the pack.
         ///
-        /// See here for a list of supported URLs: https://www.git-scm.com/docs/git-clone#_git_urls
+        /// See here for a list of supported URLs: <https://www.git-scm.com/docs/git-clone#_git_urls>
         url: String,
 
         /// The directory into which to write the received pack and index.
@@ -68,17 +106,18 @@ pub enum Subcommands {
     /// List remote references from a remote identified by a url.
     ///
     /// This is the plumbing equivalent of `git ls-remote`.
-    /// Supported URLs are documented here: https://www.git-scm.com/docs/git-clone#_git_urls
+    /// Supported URLs are documented here: <https://www.git-scm.com/docs/git-clone#_git_urls>
     #[clap(setting = AppSettings::ColoredHelp)]
     #[clap(setting = AppSettings::DisableVersion)]
+    #[cfg(any(feature = "gitoxide-core-async-client", feature = "gitoxide-core-blocking-client"))]
     RemoteRefList {
         /// The protocol version to use. Valid values are 1 and 2
         #[clap(long, short = 'p')]
-        protocol: Option<core::Protocol>,
+        protocol: Option<core::net::Protocol>,
 
         /// the URLs or path from which to receive references
         ///
-        /// See here for a list of supported URLs: https://www.git-scm.com/docs/git-clone#_git_urls
+        /// See here for a list of supported URLs: <https://www.git-scm.com/docs/git-clone#_git_urls>
         url: String,
     },
     #[clap(setting = AppSettings::ColoredHelp)]
